==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/statistiques/lang/statistiques_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/statistiques?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'archiver' => 'Archiviare',
	'archiver_concatener_explications' => 'Questa operazione collegherà le statistiche di visita degli articoli :',
	'archiver_concatener_ignorer' => 'Le visite di meno di @nb@ anni non  verranno toccate.',
	'archiver_concatener_par_an' => 'I dati di visita di più di @nb@ anni saranno ridotti ad un’unica voce, per ogni articolo, il primo giorno di ogni anno.',
	'archiver_concatener_par_mois' => 'I dati di visita di più di @nb@ anni saranno ridotti ad un’unica voce, per ogni articolo, il primo giorno di ogni mese.',
	'archiver_conseil_sauvegarde' => 'E’ consigliabile un salvataggio preliminare del database.',
	'archiver_description' => 'Questa pagina fornisce i mezzi necessari alla pulizia o all’archiviazione delle statistiche del sito.',
	'archiver_et_nettoyer' => 'Archiviazione e pulizia',
	'archiver_nettoyer' => 'Pulizia',
	'archiver_nettoyer_explications' => 'Elimina le righe dei riferimenti o delle visite per gli articoli inesistenti (o non più esistenti) dal database.',
	'archiver_nettoyer_referers_articles' => 'Ripulire i riferimenti degli articoli',
	'archiver_nettoyer_visites_articles' => 'Ripulire le visite degli articoli',
	'archiver_nombre_lignes' => 'Numero di righe',
	'archiver_operation_longue' => 'Questa operazione potrebbe richiedere molto tempo, soprattutto se si tratta della prima volta che viene effettuata.',
	'archiver_operations_irreversibles' => 'Queste operazioni sono irreversibili!',

	// B
	'bouton_effacer_referers' => 'Eliminare solo i collegamenti in entrata',
	'bouton_effacer_statistiques' => 'Cancellare le statistiche',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Evoluzione delle visite<br />@visites@ visite',
	'icone_repartition_actuelle' => 'Mostra la ripartizione attuale',
	'icone_repartition_visites' => 'Distribuzione delle visite',
	'icone_statistiques_visites' => 'Statistiche delle visite',
	'info_affichier_visites_articles_plus_visites' => 'Mostra le visite per <b>gli articoli più letti dall’inaugurazione del sito:</b>',
	'info_comment_lire_tableau' => 'Come leggere questa tabella',
	'info_forum_statistiques' => 'Statistiche delle visite',
	'info_graphiques' => 'Grafici',
	'info_popularite_2' => 'popolarità del sito: ',
	'info_popularite_3' => 'popolarità: @popularite@; visite: @visites@',
	'info_popularite_5' => 'popolarità:',
	'info_previsions' => 'previsioni :',
	'info_question_vignettes_referer' => 'Quando si consultano le statistiche è possibile visualizzare delle anteprime dei siti di origine delle visite',
	'info_question_vignettes_referer_oui' => 'Visualizzare le catture di schermo dei siti di origine delle visite',
	'info_tableaux' => 'Tabelle',
	'info_visites' => 'visite:',
	'info_visites_plus_populaires' => 'Pubblica le visite per <b>gli articoli più popolari </b> e per <b>gli ultimi articoli pubblicati:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gestisci le statistiche delle visite',

	// O
	'onglet_origine_visites' => 'Origine delle visite',
	'onglet_repartition_debut' => 'dall’inizio',
	'onglet_repartition_lang' => 'Suddivisione per lingua',

	// R
	'resume' => 'Riassunto',

	// T
	'texte_admin_effacer_stats' => 'Questo comando cancella tutti i dati collegati alle statistiche delle visite al sito, comprese la popolarità degli articoli.',
	'texte_admin_effacer_toutes_stats' => 'Il pulsante elimina tutte le statistiche: visite, popolarità degli articoli, e connessioni entranti.',
	'texte_comment_lire_tableau' => 'Il posizionamento dell’articolo,
nella classifica per popolarità, è indicato qui
sopra. La popolarità dell’articolo (una stima del
numero di visite quotidiane che riceverà rimanendo costante il ritmo attuale di
consultazione) e il numero di visite ricevute dall’inizio,
sono visualizzati nel commento che appare
quando si passa con il mouse sopra al titolo.',
	'texte_signification' => 'Le barre più scure rappresentano le entrate accumulate (per il totale delle sottorubriche), le barre più chiare il numero di visite per ogni rubrica.',
	'titre_evolution_visite' => 'Evoluzione delle visite',
	'titre_liens_entrants' => 'I link odierni al tuo sito',
	'titre_page_statistiques' => 'Statistiche per rubrica',
	'titre_page_statistiques_visites' => 'Statistiche delle visite',

	// V
	'visites_journalieres' => 'Numero di visite per giorno',
	'visites_mensuelles' => 'Numero di visite per mese'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/statistiques/lang/statistiques_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/statistiques?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'archiver' => 'Archiviare',
	'archiver_concatener_explications' => 'Questa operazione collegherà le statistiche di visita degli articoli :',
	'archiver_concatener_ignorer' => 'Le visite di meno di @nb@ anni non  verranno toccate.',
	'archiver_concatener_par_an' => 'I dati di visita di più di @nb@ anni saranno ridotti ad un’unica voce, per ogni articolo, il primo giorno di ogni anno.',
	'archiver_concatener_par_mois' => 'I dati di visita di più di @nb@ anni saranno ridotti ad un’unica voce, per ogni articolo, il primo giorno di ogni mese.',
	'archiver_conseil_sauvegarde' => 'E’ consigliabile un salvataggio preliminare del database.',
	'archiver_description' => 'Questa pagina fornisce i mezzi necessari alla pulizia o all’archiviazione delle statistiche del sito.',
	'archiver_et_nettoyer' => 'Archiviazione e pulizia',
	'archiver_nettoyer' => 'Pulizia',
	'archiver_nettoyer_explications' => 'Elimina le righe dei riferimenti o delle visite per gli articoli inesistenti (o non più esistenti) dal database.', # MODIF
	'archiver_nettoyer_referers_articles' => 'Ripulire i riferimenti degli articoli', # MODIF
	'archiver_nettoyer_visites_articles' => 'Ripulire le visite degli articoli', # MODIF
	'archiver_nombre_lignes' => 'Numero di righe',
	'archiver_operation_longue' => 'Questa operazione potrebbe richiedere molto tempo, soprattutto se si tratta della prima volta che viene effettuata.',
	'archiver_operations_irreversibles' => 'Queste operazioni sono irreversibili!',

	// B
	'bouton_effacer_referers' => 'Eliminare solo i collegamenti in entrata',
	'bouton_effacer_statistiques' => 'Cancellare le statistiche',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Evoluzione delle visite<br />@visites@ visite',
	'icone_repartition_actuelle' => 'Mostra la ripartizione attuale',
	'icone_repartition_visites' => 'Distribuzione delle visite',
	'icone_statistiques_visites' => 'Statistiche delle visite',
	'info_affichier_visites_articles_plus_visites' => 'Mostra le visite per <b>gli articoli più letti dall’inaugurazione del sito:</b>',
	'info_comment_lire_tableau' => 'Come leggere questa tabella',
	'info_forum_statistiques' => 'Statistiche delle visite',
	'info_graphiques' => 'Grafici',
	'info_popularite_2' => 'popolarità del sito: ',
	'info_popularite_3' => 'popolarità: @popularite@; visite: @visites@',
	'info_popularite_5' => 'popolarità:',
	'info_previsions' => 'previsioni :',
	'info_question_vignettes_referer' => 'Quando si consultano le statistiche è possibile visualizzare delle anteprime dei siti di origine delle visite',
	'info_question_vignettes_referer_oui' => 'Visualizzare le catture di schermo dei siti di origine delle visite',
	'info_tableaux' => 'Tabelle',
	'info_visites' => 'visite:',
	'info_visites_plus_populaires' => 'Pubblica le visite per <b>gli articoli più popolari </b> e per <b>gli ultimi articoli pubblicati:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gestisci le statistiche delle visite',

	// O
	'onglet_origine_visites' => 'Origine delle visite',
	'onglet_repartition_debut' => 'dall’inizio',
	'onglet_repartition_lang' => 'Suddivisione per lingua',

	// R
	'resume' => 'Riassunto',

	// T
	'texte_admin_effacer_stats' => 'Questo comando cancella tutti i dati collegati alle statistiche delle visite al sito, comprese la popolarità degli articoli.',
	'texte_admin_effacer_toutes_stats' => 'Il pulsante elimina tutte le statistiche: visite, popolarità degli articoli, e connessioni entranti.',
	'texte_comment_lire_tableau' => 'Il posizionamento dell’articolo,
nella classifica per popolarità, è indicato qui
sopra. La popolarità dell’articolo (una stima del
numero di visite quotidiane che riceverà rimanendo costante il ritmo attuale di
consultazione) e il numero di visite ricevute dall’inizio,
sono visualizzati nel commento che appare
quando si passa con il mouse sopra al titolo.',
	'texte_signification' => 'Le barre più scure rappresentano le entrate accumulate (per il totale delle sottorubriche), le barre più chiare il numero di visite per ogni rubrica.',
	'titre_evolution_visite' => 'Evoluzione delle visite',
	'titre_liens_entrants' => 'I link odierni al tuo sito',
	'titre_page_statistiques' => 'Statistiche per rubrica',
	'titre_page_statistiques_visites' => 'Statistiche delle visite',

	// V
	'visites_journalieres' => 'Numero di visite per giorno',
	'visites_mensuelles' => 'Numero di visite per mese'
);

?>
